// generated from rosidl_generator_c/resource/idl.h.em
// with input from std_msgs:msg/Int16.idl
// generated code does not contain a copyright notice

#ifndef STD_MSGS__MSG__INT16_H_
#define STD_MSGS__MSG__INT16_H_

#include "std_msgs/msg/detail/int16__struct.h"
#include "std_msgs/msg/detail/int16__functions.h"
#include "std_msgs/msg/detail/int16__type_support.h"

#endif  // STD_MSGS__MSG__INT16_H_
